@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class AppInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Appkey: 应用key
@@ -67,7 +67,7 @@ class AppInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -77,7 +77,7 @@ class CardInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Iccid: 卡片ID
         :type Iccid: str
         :param Msisdn: 卡电话号码
@@ -150,6 +150,9 @@ class CardInfo(AbstractModel):
         :param CertificationState: 实名认证 0:无 1:未实名 2:已实名
 注意：此字段可能返回 null，表示取不到有效值。
         :type CertificationState: int
+        :param OtherData: 其他流量信息,流量分离统计其他流量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OtherData: float
         """
         self.Iccid = None
         self.Msisdn = None
@@ -178,6 +181,7 @@ class CardInfo(AbstractModel):
         self.NeedSms = None
         self.Provider = None
         self.CertificationState = None
+        self.OtherData = None
 
 
     def _deserialize(self, params):
@@ -208,12 +212,13 @@ class CardInfo(AbstractModel):
         self.NeedSms = params.get("NeedSms")
         self.Provider = params.get("Provider")
         self.CertificationState = params.get("CertificationState")
+        self.OtherData = params.get("OtherData")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -223,7 +228,7 @@ class CardList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Total: 卡片总数
         :type Total: str
         :param List: 卡片列表信息
@@ -247,7 +252,7 @@ class CardList(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -257,7 +262,7 @@ class DescribeAppRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 物联卡应用ID
         :type Sdkappid: int
         """
@@ -271,7 +276,7 @@ class DescribeAppRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -281,7 +286,7 @@ class DescribeAppResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 应用信息详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.AppInfo`
@@ -297,13 +302,6 @@ class DescribeAppResponse(AbstractModel):
             self.Data = AppInfo()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCardRequest(AbstractModel):
@@ -312,7 +310,7 @@ class DescribeCardRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 卡片ID
@@ -330,7 +328,7 @@ class DescribeCardRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -340,7 +338,7 @@ class DescribeCardResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 卡片详细信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.CardInfo`
@@ -356,13 +354,6 @@ class DescribeCardResponse(AbstractModel):
             self.Data = CardInfo()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeCardsRequest(AbstractModel):
@@ -371,7 +362,7 @@ class DescribeCardsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Offset: 偏移值
@@ -393,7 +384,7 @@ class DescribeCardsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -403,7 +394,7 @@ class DescribeCardsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 卡片列表信息
         :type Data: :class:`tencentcloud.ic.v20190307.models.CardList`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -418,13 +409,6 @@ class DescribeCardsResponse(AbstractModel):
             self.Data = CardList()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ModifyUserCardRemarkRequest(AbstractModel):
@@ -433,7 +417,7 @@ class ModifyUserCardRemarkRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 物联卡ICCID
@@ -455,7 +439,7 @@ class ModifyUserCardRemarkRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -465,7 +449,7 @@ class ModifyUserCardRemarkResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -474,13 +458,6 @@ class ModifyUserCardRemarkResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class RenewCardsRequest(AbstractModel):
@@ -489,7 +466,7 @@ class RenewCardsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccids: 续费的iccid
@@ -511,7 +488,7 @@ class RenewCardsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -521,7 +498,7 @@ class RenewCardsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 续费成功的订单id
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.ResRenew`
@@ -537,13 +514,6 @@ class RenewCardsResponse(AbstractModel):
             self.Data = ResRenew()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ResRenew(AbstractModel):
@@ -552,7 +522,7 @@ class ResRenew(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param OrderIds: 每一张续费卡片的订单ID数组
 注意：此字段可能返回 null，表示取不到有效值。
         :type OrderIds: list of str
@@ -567,7 +537,7 @@ class ResRenew(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -577,7 +547,7 @@ class SendMultiSmsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Iccids: 卡片列表
@@ -599,7 +569,7 @@ class SendMultiSmsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -609,7 +579,7 @@ class SendMultiSmsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 短信流水数组
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: list of SmsRet
@@ -628,13 +598,6 @@ class SendMultiSmsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Data.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SendSmsRequest(AbstractModel):
@@ -643,7 +606,7 @@ class SendSmsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 卡片ID
@@ -665,7 +628,7 @@ class SendSmsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -675,7 +638,7 @@ class SendSmsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 短信流水信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.SmsSid`
@@ -691,13 +654,6 @@ class SendSmsResponse(AbstractModel):
             self.Data = SmsSid()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SmsRet(AbstractModel):
@@ -706,7 +662,7 @@ class SmsRet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Code: 该iccid请求状态
         :type Code: str
         :param Msg: 短信发送返回信息
@@ -732,7 +688,7 @@ class SmsRet(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -742,7 +698,7 @@ class SmsSid(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Iccid: 卡片ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type Iccid: str
@@ -761,5 +717,5 @@ class SmsSid(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
